@@ -1,21 +1,20 @@
 import json
-
-from requests import Session
+from datetime import datetime
 
 from pdchaoskit.api import endpoints, get_error_message
+from requests import Session
 
 
 def publish_event(name, context, state, settings, session: Session):
-    id = settings.get('run_context').get('execution_id', None)
+    id = settings.get('run_context').get('execution').get('id', None)
     if not id:
         raise Exception("Experiment run identifier cannot be empty.")
     data = json.dumps({
-        'source': 'chaos.execution',
         'name': name,
-        'execution_id': id,
         'state': state,
-        'context': context
+        'context': context,
+        'timestamp': datetime.utcnow().isoformat()
     })
-    response = session.post(endpoints.events(), data=data, timeout=30)
+    response = session.post(endpoints.events(id), data=data, timeout=30)
     if not response.ok:
         raise Exception(get_error_message(response))
