@@ -8,10 +8,9 @@ from pdchaoskit.settings import get_api_token, get_api_url
 
 
 @contextmanager
-def client_session(verify_tls: bool = True, settings: Settings = None) \
-                       -> Generator[Session, None, None]:
+def client_session(verify_tls: bool = True, settings: Settings = None) -> Generator[Session, None, None]:
 
-    # read the token from the auths block
+    # prepare auth token
     api_url = get_api_url(settings)
     api_token = get_api_token(settings, api_url)
     headers = {
